@@ -37,7 +37,7 @@ TextReplaceWidget::TextReplaceWidget(QWidget *parent)
     const int marg = lay->margin();
     lay->setContentsMargins(marg, 0, marg, 0);
 
-    mReplace = new QLineEdit;
+    mReplace = new QLineEdit(this);
     mReplace->setClearButtonEnabled(true);
     lay->addWidget(mReplace);
 
@@ -121,7 +121,7 @@ TextFindWidget::~TextFindWidget()
 
 QRegExp TextFindWidget::findRegExp() const
 {
-    QString str = mSearch->text();
+    QString str = QRegExp::escape(mSearch->text());
     if (mWholeWordAct->isChecked()) {
         str = QLatin1String("\\b") + str + QLatin1String("\\b");
     }
